go.dev: fix module path to make trybots happy

For golang/go#46501.

Change-Id: Ie2adbc3536570e66ffda1227ffd4431fe4bf870a
Reviewed-on: https://go-review.googlesource.com/c/website/+/324411
Trust: Russ Cox <rsc@golang.org>
Run-TryBot: Russ Cox <rsc@golang.org>
Website-Publish: Russ Cox <rsc@golang.org>
Reviewed-by: Dmitri Shuralyov <dmitshur@golang.org>
diff --git a/go.dev/cmd/frontend/main.go b/go.dev/cmd/frontend/main.go
index 3d9e0a4..895cce3 100644
--- a/go.dev/cmd/frontend/main.go
+++ b/go.dev/cmd/frontend/main.go
@@ -12,7 +12,7 @@
 	"os"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/site"
+	"golang.org/x/website/go.dev/cmd/internal/site"
 )
 
 var discoveryHosts = map[string]string{
diff --git a/go.dev/cmd/frontend/main_test.go b/go.dev/cmd/frontend/main_test.go
index 8f25d39..61c7d0f 100644
--- a/go.dev/cmd/frontend/main_test.go
+++ b/go.dev/cmd/frontend/main_test.go
@@ -11,7 +11,7 @@
 	"strings"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/site"
+	"golang.org/x/website/go.dev/cmd/internal/site"
 )
 
 var testHosts = map[string]string{
diff --git a/go.dev/cmd/internal/fmtsort/sort_test.go b/go.dev/cmd/internal/fmtsort/sort_test.go
index 93b7b3f..5c73fce 100644
--- a/go.dev/cmd/internal/fmtsort/sort_test.go
+++ b/go.dev/cmd/internal/fmtsort/sort_test.go
@@ -12,7 +12,7 @@
 	"testing"
 	"unsafe"
 
-	"golang.org/x/go.dev/cmd/internal/fmtsort"
+	"golang.org/x/website/go.dev/cmd/internal/fmtsort"
 )
 
 var compareTests = [][]reflect.Value{
diff --git a/go.dev/cmd/internal/html/template/clone_test.go b/go.dev/cmd/internal/html/template/clone_test.go
index ef68dc7..c42d241 100644
--- a/go.dev/cmd/internal/html/template/clone_test.go
+++ b/go.dev/cmd/internal/html/template/clone_test.go
@@ -13,7 +13,7 @@
 	"sync"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 func TestAddParseTreeHTML(t *testing.T) {
diff --git a/go.dev/cmd/internal/html/template/content_test.go b/go.dev/cmd/internal/html/template/content_test.go
index bb1667b..70cbd4e 100644
--- a/go.dev/cmd/internal/html/template/content_test.go
+++ b/go.dev/cmd/internal/html/template/content_test.go
@@ -216,7 +216,7 @@
 		},
 		{
 			// Not treated as JS. The output is same as for <div>{{.}}</div>
-			`<script type="golang.org/x/go.dev/cmd/internal/text/template">{{.}}</script>`,
+			`<script type="golang.org/x/website/go.dev/cmd/internal/text/template">{{.}}</script>`,
 			[]string{
 				`&lt;b&gt; &#34;foo%&#34; O&#39;Reilly &amp;bar;`,
 				`a[href =~ &#34;//example.com&#34;]#foo`,
diff --git a/go.dev/cmd/internal/html/template/context.go b/go.dev/cmd/internal/html/template/context.go
index 850022a..9b74fe7 100644
--- a/go.dev/cmd/internal/html/template/context.go
+++ b/go.dev/cmd/internal/html/template/context.go
@@ -7,7 +7,7 @@
 import (
 	"fmt"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // context describes the state an HTML parser must be in when it reaches the
diff --git a/go.dev/cmd/internal/html/template/doc.go b/go.dev/cmd/internal/html/template/doc.go
index 2abc215..fb3f173 100644
--- a/go.dev/cmd/internal/html/template/doc.go
+++ b/go.dev/cmd/internal/html/template/doc.go
@@ -34,7 +34,7 @@
 
 Example
 
-  import "golang.org/x/go.dev/cmd/internal/text/template"
+  import "golang.org/x/website/go.dev/cmd/internal/text/template"
   ...
   t, err := template.New("foo").Parse(`{{define "T"}}Hello, {{.}}!{{end}}`)
   err = t.ExecuteTemplate(out, "T", "<script>alert('you have been pwned')</script>")
@@ -45,7 +45,7 @@
 
 but the contextual autoescaping in html/template
 
-  import "golang.org/x/go.dev/cmd/internal/html/template"
+  import "golang.org/x/website/go.dev/cmd/internal/html/template"
   ...
   t, err := template.New("foo").Parse(`{{define "T"}}Hello, {{.}}!{{end}}`)
   err = t.ExecuteTemplate(out, "T", "<script>alert('you have been pwned')</script>")
diff --git a/go.dev/cmd/internal/html/template/error.go b/go.dev/cmd/internal/html/template/error.go
index 49f0a43..c8a041f 100644
--- a/go.dev/cmd/internal/html/template/error.go
+++ b/go.dev/cmd/internal/html/template/error.go
@@ -7,7 +7,7 @@
 import (
 	"fmt"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // Error describes a problem encountered during template Escaping.
@@ -218,13 +218,13 @@
 	switch {
 	case e.Node != nil:
 		loc, _ := (*parse.Tree)(nil).ErrorContext(e.Node)
-		return fmt.Sprintf("golang.org/x/go.dev/cmd/internal/html/template:%s: %s", loc, e.Description)
+		return fmt.Sprintf("golang.org/x/website/go.dev/cmd/internal/html/template:%s: %s", loc, e.Description)
 	case e.Line != 0:
-		return fmt.Sprintf("golang.org/x/go.dev/cmd/internal/html/template:%s:%d: %s", e.Name, e.Line, e.Description)
+		return fmt.Sprintf("golang.org/x/website/go.dev/cmd/internal/html/template:%s:%d: %s", e.Name, e.Line, e.Description)
 	case e.Name != "":
-		return fmt.Sprintf("golang.org/x/go.dev/cmd/internal/html/template:%s: %s", e.Name, e.Description)
+		return fmt.Sprintf("golang.org/x/website/go.dev/cmd/internal/html/template:%s: %s", e.Name, e.Description)
 	}
-	return "golang.org/x/go.dev/cmd/internal/html/template: " + e.Description
+	return "golang.org/x/website/go.dev/cmd/internal/html/template: " + e.Description
 }
 
 // errorf creates an error given a format string f and args.
diff --git a/go.dev/cmd/internal/html/template/escape.go b/go.dev/cmd/internal/html/template/escape.go
index 2ad5996..959c871 100644
--- a/go.dev/cmd/internal/html/template/escape.go
+++ b/go.dev/cmd/internal/html/template/escape.go
@@ -10,8 +10,8 @@
 	"html"
 	"io"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // escapeTemplate rewrites the named template, which must be
diff --git a/go.dev/cmd/internal/html/template/escape_test.go b/go.dev/cmd/internal/html/template/escape_test.go
index 8ead4f7..8152ca2 100644
--- a/go.dev/cmd/internal/html/template/escape_test.go
+++ b/go.dev/cmd/internal/html/template/escape_test.go
@@ -12,8 +12,8 @@
 	"strings"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 type badMarshaler struct{}
@@ -1047,7 +1047,7 @@
 		},
 		{
 			"<a class=`foo>",
-			"golang.org/x/go.dev/cmd/internal/html/template:z: \"`\" in unquoted attr: \"`foo\"",
+			"golang.org/x/website/go.dev/cmd/internal/html/template:z: \"`\" in unquoted attr: \"`foo\"",
 		},
 		{
 			`<a style=font:'Arial'>`,
@@ -1505,7 +1505,7 @@
 			context{state: stateText},
 		},
 		{
-			`<script type="golang.org/x/go.dev/cmd/internal/text/template">`,
+			`<script type="golang.org/x/website/go.dev/cmd/internal/text/template">`,
 			context{state: stateText},
 		},
 		// covering issue 19968
@@ -1515,7 +1515,7 @@
 		},
 		// covering issue 19965
 		{
-			`<script TYPE="golang.org/x/go.dev/cmd/internal/text/template">`,
+			`<script TYPE="golang.org/x/website/go.dev/cmd/internal/text/template">`,
 			context{state: stateText},
 		},
 		{
diff --git a/go.dev/cmd/internal/html/template/example_test.go b/go.dev/cmd/internal/html/template/example_test.go
index f8f7af9..3ec1b60 100644
--- a/go.dev/cmd/internal/html/template/example_test.go
+++ b/go.dev/cmd/internal/html/template/example_test.go
@@ -10,7 +10,7 @@
 	"os"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/html/template"
+	"golang.org/x/website/go.dev/cmd/internal/html/template"
 )
 
 func Example() {
diff --git a/go.dev/cmd/internal/html/template/examplefiles_test.go b/go.dev/cmd/internal/html/template/examplefiles_test.go
index 82f1676..1ff585d 100644
--- a/go.dev/cmd/internal/html/template/examplefiles_test.go
+++ b/go.dev/cmd/internal/html/template/examplefiles_test.go
@@ -11,7 +11,7 @@
 	"os"
 	"path/filepath"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 // templateFile defines the contents of a template to be stored in a file, for testing.
diff --git a/go.dev/cmd/internal/html/template/exec_test.go b/go.dev/cmd/internal/html/template/exec_test.go
index f85a130..6bd824c 100644
--- a/go.dev/cmd/internal/html/template/exec_test.go
+++ b/go.dev/cmd/internal/html/template/exec_test.go
@@ -17,7 +17,7 @@
 	"sync"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 var debug = flag.Bool("debug", false, "show the errors produced by the tests")
diff --git a/go.dev/cmd/internal/html/template/multi_test.go b/go.dev/cmd/internal/html/template/multi_test.go
index e6c1167..30247ce 100644
--- a/go.dev/cmd/internal/html/template/multi_test.go
+++ b/go.dev/cmd/internal/html/template/multi_test.go
@@ -10,7 +10,7 @@
 	"bytes"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 var multiExecTests = []execTest{
diff --git a/go.dev/cmd/internal/html/template/template_test.go b/go.dev/cmd/internal/html/template/template_test.go
index 5df2d02..c04c43e 100644
--- a/go.dev/cmd/internal/html/template/template_test.go
+++ b/go.dev/cmd/internal/html/template/template_test.go
@@ -10,8 +10,8 @@
 	"strings"
 	"testing"
 
-	. "golang.org/x/go.dev/cmd/internal/html/template"
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	. "golang.org/x/website/go.dev/cmd/internal/html/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 func TestTemplateClone(t *testing.T) {
diff --git a/go.dev/cmd/internal/site/md.go b/go.dev/cmd/internal/site/md.go
index 72ac255..c36c18c 100644
--- a/go.dev/cmd/internal/site/md.go
+++ b/go.dev/cmd/internal/site/md.go
@@ -16,8 +16,8 @@
 	"github.com/yuin/goldmark/renderer/html"
 	"github.com/yuin/goldmark/text"
 	"github.com/yuin/goldmark/util"
-	"golang.org/x/go.dev/cmd/internal/html/template"
-	"golang.org/x/go.dev/cmd/internal/tmplfunc"
+	"golang.org/x/website/go.dev/cmd/internal/html/template"
+	"golang.org/x/website/go.dev/cmd/internal/tmplfunc"
 )
 
 // markdownToHTML converts markdown to HTML using the renderer and settings that Hugo uses.
diff --git a/go.dev/cmd/internal/site/page.go b/go.dev/cmd/internal/site/page.go
index 5c9a7da..ed080be 100644
--- a/go.dev/cmd/internal/site/page.go
+++ b/go.dev/cmd/internal/site/page.go
@@ -12,7 +12,7 @@
 	"strings"
 	"time"
 
-	"golang.org/x/go.dev/cmd/internal/tmplfunc"
+	"golang.org/x/website/go.dev/cmd/internal/tmplfunc"
 	"gopkg.in/yaml.v3"
 )
 
diff --git a/go.dev/cmd/internal/site/site.go b/go.dev/cmd/internal/site/site.go
index f54077e..f33421c 100644
--- a/go.dev/cmd/internal/site/site.go
+++ b/go.dev/cmd/internal/site/site.go
@@ -20,7 +20,7 @@
 	"strings"
 	"time"
 
-	"golang.org/x/go.dev/cmd/internal/html/template"
+	"golang.org/x/website/go.dev/cmd/internal/html/template"
 	"gopkg.in/yaml.v3"
 )
 
diff --git a/go.dev/cmd/internal/site/tmpl.go b/go.dev/cmd/internal/site/tmpl.go
index e245fd0..a7ad25a 100644
--- a/go.dev/cmd/internal/site/tmpl.go
+++ b/go.dev/cmd/internal/site/tmpl.go
@@ -9,8 +9,8 @@
 	"reflect"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/html/template"
-	"golang.org/x/go.dev/cmd/internal/tmplfunc"
+	"golang.org/x/website/go.dev/cmd/internal/html/template"
+	"golang.org/x/website/go.dev/cmd/internal/tmplfunc"
 	"gopkg.in/yaml.v3"
 )
 
diff --git a/go.dev/cmd/internal/text/template/example_test.go b/go.dev/cmd/internal/text/template/example_test.go
index 48a136a..5f2e806 100644
--- a/go.dev/cmd/internal/text/template/example_test.go
+++ b/go.dev/cmd/internal/text/template/example_test.go
@@ -9,7 +9,7 @@
 	"os"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 func ExampleTemplate() {
diff --git a/go.dev/cmd/internal/text/template/examplefiles_test.go b/go.dev/cmd/internal/text/template/examplefiles_test.go
index bb90c6b..b80a9e2 100644
--- a/go.dev/cmd/internal/text/template/examplefiles_test.go
+++ b/go.dev/cmd/internal/text/template/examplefiles_test.go
@@ -11,7 +11,7 @@
 	"os"
 	"path/filepath"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 // templateFile defines the contents of a template to be stored in a file, for testing.
diff --git a/go.dev/cmd/internal/text/template/examplefunc_test.go b/go.dev/cmd/internal/text/template/examplefunc_test.go
index 03babf3..826c25c 100644
--- a/go.dev/cmd/internal/text/template/examplefunc_test.go
+++ b/go.dev/cmd/internal/text/template/examplefunc_test.go
@@ -9,7 +9,7 @@
 	"os"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 // This example demonstrates a custom function to process template text.
diff --git a/go.dev/cmd/internal/text/template/exec.go b/go.dev/cmd/internal/text/template/exec.go
index 35fbecb..be8835a 100644
--- a/go.dev/cmd/internal/text/template/exec.go
+++ b/go.dev/cmd/internal/text/template/exec.go
@@ -12,8 +12,8 @@
 	"runtime"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/fmtsort"
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/fmtsort"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // maxExecDepth specifies the maximum stack depth of templates within
diff --git a/go.dev/cmd/internal/text/template/multi_test.go b/go.dev/cmd/internal/text/template/multi_test.go
index b917e72..8507c63 100644
--- a/go.dev/cmd/internal/text/template/multi_test.go
+++ b/go.dev/cmd/internal/text/template/multi_test.go
@@ -11,7 +11,7 @@
 	"fmt"
 	"testing"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 const (
diff --git a/go.dev/cmd/internal/text/template/template.go b/go.dev/cmd/internal/text/template/template.go
index 877674e..5ba31da 100644
--- a/go.dev/cmd/internal/text/template/template.go
+++ b/go.dev/cmd/internal/text/template/template.go
@@ -8,7 +8,7 @@
 	"reflect"
 	"sync"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // common holds the information shared by related templates.
diff --git a/go.dev/cmd/internal/tmplfunc/func.go b/go.dev/cmd/internal/tmplfunc/func.go
index 92b62be..9ea117b 100644
--- a/go.dev/cmd/internal/tmplfunc/func.go
+++ b/go.dev/cmd/internal/tmplfunc/func.go
@@ -11,10 +11,10 @@
 	"regexp"
 	"strings"
 
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 
-	htmltemplate "golang.org/x/go.dev/cmd/internal/html/template"
-	texttemplate "golang.org/x/go.dev/cmd/internal/text/template"
+	htmltemplate "golang.org/x/website/go.dev/cmd/internal/html/template"
+	texttemplate "golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 var validNameRE = regexp.MustCompile(`\A[_\pL][_\pL\p{Nd}]*\z`)
diff --git a/go.dev/cmd/internal/tmplfunc/tmpl.go b/go.dev/cmd/internal/tmplfunc/tmpl.go
index 534fc43..8932685 100644
--- a/go.dev/cmd/internal/tmplfunc/tmpl.go
+++ b/go.dev/cmd/internal/tmplfunc/tmpl.go
@@ -84,8 +84,8 @@
 	"io/ioutil"
 	"path/filepath"
 
-	htmltemplate "golang.org/x/go.dev/cmd/internal/html/template"
-	texttemplate "golang.org/x/go.dev/cmd/internal/text/template"
+	htmltemplate "golang.org/x/website/go.dev/cmd/internal/html/template"
+	texttemplate "golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 // A Template is a *template.Template, where template refers to either
diff --git a/go.dev/cmd/internal/tmplfunc/tmplfunc_test.go b/go.dev/cmd/internal/tmplfunc/tmplfunc_test.go
index 161a49c..ee555ad 100644
--- a/go.dev/cmd/internal/tmplfunc/tmplfunc_test.go
+++ b/go.dev/cmd/internal/tmplfunc/tmplfunc_test.go
@@ -10,8 +10,8 @@
 	"strings"
 	"testing"
 
-	htmltemplate "golang.org/x/go.dev/cmd/internal/html/template"
-	texttemplate "golang.org/x/go.dev/cmd/internal/text/template"
+	htmltemplate "golang.org/x/website/go.dev/cmd/internal/html/template"
+	texttemplate "golang.org/x/website/go.dev/cmd/internal/text/template"
 )
 
 var tests = []struct {
diff --git a/go.dev/go.mod b/go.dev/go.mod
index 91e27b1..37706b9 100644
--- a/go.dev/go.mod
+++ b/go.dev/go.mod
@@ -1,4 +1,4 @@
-module golang.org/x/go.dev
+module golang.org/x/website/go.dev
 
 go 1.13
diff --git a/go.dev/cmd/internal/html/template/template.go b/go.dev/cmd/internal/html/template/template.go
index f3375f5..1de4bd5 100644
--- a/go.dev/cmd/internal/html/template/template.go
+++ b/go.dev/cmd/internal/html/template/template.go
@@ -11,11 +11,11 @@
 	"path/filepath"
 	"sync"
 
-	"golang.org/x/go.dev/cmd/internal/text/template"
-	"golang.org/x/go.dev/cmd/internal/text/template/parse"
+	"golang.org/x/website/go.dev/cmd/internal/text/template"
+	"golang.org/x/website/go.dev/cmd/internal/text/template/parse"
 )
 
 // Template is a specialized Template from "golang.org/x/go.dev/cmd/internal/text/template" that produces a safe
 // HTML document fragment.
 type Template struct {
 	// Sticky error if escaping fails, or escapeOK if succeeded.
@@ -86,7 +86,7 @@
 	t.nameSpace.mu.Lock()
 	defer t.nameSpace.mu.Unlock()
 	if t.nameSpace.escaped {
-		return fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: cannot Parse after Execute")
+		return fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: cannot Parse after Execute")
 	}
 	return nil
 }
@@ -147,16 +147,16 @@
 	t.nameSpace.escaped = true
 	tmpl = t.set[name]
 	if tmpl == nil {
-		return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: %q is undefined", name)
+		return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: %q is undefined", name)
 	}
 	if tmpl.escapeErr != nil && tmpl.escapeErr != escapeOK {
 		return nil, tmpl.escapeErr
 	}
 	if tmpl.text.Tree == nil || tmpl.text.Root == nil {
-		return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: %q is an incomplete template", name)
+		return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: %q is an incomplete template", name)
 	}
 	if t.text.Lookup(name) == nil {
-		panic("golang.org/x/go.dev/cmd/internal/html/template internal error: template escaping out of sync")
+		panic("golang.org/x/website/go.dev/cmd/internal/html/template internal error: template escaping out of sync")
 	}
 	if tmpl.escapeErr == nil {
 		err = escapeTemplate(tmpl, tmpl.text.Root, name)
@@ -246,7 +246,7 @@
 	t.nameSpace.mu.Lock()
 	defer t.nameSpace.mu.Unlock()
 	if t.escapeErr != nil {
-		return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: cannot Clone %q after it has executed", t.Name())
+		return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: cannot Clone %q after it has executed", t.Name())
 	}
 	textClone, err := t.text.Clone()
 	if err != nil {
@@ -265,7 +265,7 @@
 		name := x.Name()
 		src := t.set[name]
 		if src == nil || src.escapeErr != nil {
-			return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: cannot Clone %q after it has executed", t.Name())
+			return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: cannot Clone %q after it has executed", t.Name())
 		}
 		x.Tree = x.Tree.Copy()
 		ret.set[name] = &Template{
@@ -332,8 +332,8 @@
 // return values of which the second has type error. In that case, if the
 // second (error) argument evaluates to non-nil during execution, execution
 // terminates and Execute returns that error. FuncMap has the same base type
 // as FuncMap in "golang.org/x/go.dev/cmd/internal/text/template", copied here so clients need not import
 // "golang.org/x/go.dev/cmd/internal/text/template".
 type FuncMap map[string]interface{}
 
 // Funcs adds the elements of the argument map to the template's function map.
@@ -409,7 +409,7 @@
 
 	if len(filenames) == 0 {
 		// Not really a problem, but be consistent.
-		return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: no files named in call to ParseFiles")
+		return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: no files named in call to ParseFiles")
 	}
 	for _, filename := range filenames {
 		name, b, err := readFile(filename)
@@ -477,7 +477,7 @@
 		return nil, err
 	}
 	if len(filenames) == 0 {
-		return nil, fmt.Errorf("golang.org/x/go.dev/cmd/internal/html/template: pattern matches no files: %#q", pattern)
+		return nil, fmt.Errorf("golang.org/x/website/go.dev/cmd/internal/html/template: pattern matches no files: %#q", pattern)
 	}
 	return parseFiles(t, readFileOS, filenames...)
 }
@@ -11,11 +11,11 @@
 )
 
-// Template is a specialized Template from "golang.org/x/go.dev/cmd/internal/text/template" that produces a safe
+// Template is a specialized Template from "golang.org/x/website/go.dev/cmd/internal/text/template" that produces a safe
 // HTML document fragment.
 type Template struct {
@@ -332,8 +332,8 @@
 // second (error) argument evaluates to non-nil during execution, execution
 // terminates and Execute returns that error. FuncMap has the same base type
-// as FuncMap in "golang.org/x/go.dev/cmd/internal/text/template", copied here so clients need not import
-// "golang.org/x/go.dev/cmd/internal/text/template".
+// as FuncMap in "golang.org/x/website/go.dev/cmd/internal/text/template", copied here so clients need not import
+// "golang.org/x/website/go.dev/cmd/internal/text/template".
 type FuncMap map[string]interface{}
 